@@ -1,26 +1,31 @@
-from . import email
-from . import gitter
-from . import gmail
-from . import icloud
-from . import join
-from . import mailgun
-from . import pagerduty
-from . import popcornnotify
-from . import pushbullet
-from . import pushover
-from . import simplepush
-from . import slack
-from . import statuspage
-from . import telegram
-from . import twilio
-from . import victorops
-from . import zulip
+from . import (
+    dingtalk,
+    email,
+    gitter,
+    gmail,
+    icloud,
+    join,
+    mailgun,
+    notify,
+    pagerduty,
+    popcornnotify,
+    pushbullet,
+    pushover,
+    simplepush,
+    slack,
+    statuspage,
+    telegram,
+    twilio,
+    victorops,
+    zulip,
+)
 
 _all_providers = {
     "pushover": pushover.Pushover,
     "simplepush": simplepush.SimplePush,
     "slack": slack.Slack,
     "email": email.SMTP,
+    "dingtalk": dingtalk.DingTalk,
     "gmail": gmail.Gmail,
     "icloud": icloud.iCloud,
     "telegram": telegram.Telegram,
@@ -34,4 +39,5 @@ _all_providers = {
     "popcornnotify": popcornnotify.PopcornNotify,
     "statuspage": statuspage.Statuspage,
     "victorops": victorops.VictorOps,
+    "notify": notify.Notify,
 }
